<?php
if (!is_admin())
    require_once get_template_directory() . '/library/cpanel/theme-options/typography.php';
new KopaCustomize();

class KopaCustomize {

    /**
     * An array include custom colors - selected by admin
     *
     * @var array
     */
    public $color_scheme;

    /**
     * An array include custom font (family, size, weight, line-height) - selected by admin
     * 
     * @var array
     */
    public $typography;

    public function __construct() {
        $this->color_scheme = KopaOptions::get_option('colors', '#222222');
        $this->typography = array();
        add_filter('body_class', array(&$this, 'body_class'));
        //add_action('wp_footer', array(&$this, 'wp_footer'), 20);
        add_action('wp_head', 'kopa_head');
        add_action('admin_enqueue_scripts', array(&$this, 'theme_options_enqueue'));
        add_action('wp_enqueue_scripts', array(&$this, 'enqueue_scripts'), 20);
    }

    /**
     * Modify body classes by theme-option
     *
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0
     * 
     * @param array
     * @return array
     */
    function body_class($classes) {
        global $kopaCurrentLayout;

        switch ($kopaCurrentLayout) {
            case 'front-page-3':
                $classes[] = 'kopa-home-3';
                break;
            case 'blog-page-2':
                $classes[] = 'cat-2';
                break;
            case 'error-404':
            case 'contact-page':
                $classes[] = 'kopa-contact-page';
                break;
            case 'single-post-1':
                $classes[] = 'kopa-single-page';
                break;
            case 'single-post-2':
                $classes[] = 'kopa-single2-page';
                break;
            case 'kopa-element-page':
                $classes[] = 'kopa-element-page';
                break;
            case 'media-page':
                $classes[] = 'kopa-video-page';
                $classes[] = 'kopa-gallery-page';
                break;
        }

        return array_unique($classes);
    }

    /**
     * Print custom style from Color Scheme, Typography, Custom CSS
     *
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0
     *      
     * @return NULL
     */
    function kopa_head() {
        $css = array();

        /*
         * --------------------------------------------------
         * COLOR
         * --------------------------------------------------
         */
        $primary_colors = strtolower(KopaOptions::get_option('primary_color', '#d40202'));


        /*
         * --------------------------------------------------
         * FONT
         * --------------------------------------------------
         */
        $typo_selector = array();
        foreach ($this->typography as $slug => $typo) {
            if ('off' != $typo['family']) {
                switch ($slug) {
                    case 'body_font':
                        $typo_selector[$slug] = 'body';
                        break;
                    case 'widget_title_font':
                        $typo_selector[$slug] = '#kopa-main-content h3.widget-title';
                        break;
                    case 'widget_title_footer_font':
                        $typo_selector[$slug] = '.bottom-sidebar h3.widget-title';
                        break;
                    case 'entry_title_font':
                        $typo_selector[$slug] = '.kopa-entry-post h4.entry-title';
                        break;
                    case 'entry_content_font':
                        $typo_selector[$slug] = '.kopa-entry-post .entry-content, .kopa-site-content.entry-content';
                        break;
                    case 'nav_top_font':
                        $typo_selector[$slug] = '#top-menu li a';
                        break;
                    case 'nav_bottom_font':
                        $typo_selector[$slug] = '#footer-menu li a';
                        break;
                    case 'nav_primary_font':
                        $typo_selector[$slug] = '#main-menu li a';
                        break;
                    case 'h1_font':
                        $typo_selector[$slug] = '.kopa-entry-post .entry-content h1, .kopa-site-content.entry-content h1';
                        break;
                    case 'h2_font':
                        $typo_selector[$slug] = '.kopa-entry-post .entry-content h2, .kopa-site-content.entry-content h2';
                        break;
                    case 'h3_font':
                        $typo_selector[$slug] = '.kopa-entry-post .entry-content h3, .kopa-site-content.entry-content h3';
                        break;
                    case 'h4_font':
                        $typo_selector[$slug] = '.kopa-entry-post .entry-content h4, .kopa-site-content.entry-content h4';
                        break;
                    case 'h5_font':
                        $typo_selector[$slug] = '.kopa-entry-post .entry-content h5, .kopa-site-content.entry-content h5';
                        break;
                    case 'h6_font':
                        $typo_selector[$slug] = '.kopa-entry-post .entry-content h6, .kopa-site-content.entry-content h6';
                        break;
                }
            }
        }

        if (!empty($typo_selector)) {
            foreach ($typo_selector as $slug => $selector) {
                $css[$selector]['font-family'] = "'{$this->typography[$slug]['family']}'";
                $css[$selector]['font-size'] = $this->typography[$slug]['size'] . 'px';
                $css[$selector]['font-weight'] = $this->typography[$slug]['weight'];
                $css[$selector]['line-height'] = $this->typography[$slug]['line-height'] . 'px';
                $css[$selector]['text-transform'] = $this->typography[$slug]['text-transform'];
            }
        }


        /*
         * --------------------------------------------------
         * LOGO MARGIN
         * --------------------------------------------------
         */
        $css['.kopa-logo']['margin-top'] = sprintf('%spx', KopaOptions::get_option('logo_margin_top', 0));
        $css['.kopa-logo']['margin-bottom'] = sprintf('%spx', KopaOptions::get_option('logo_margin_bottom', 0));
        $css['.kopa-logo']['margin-left'] = sprintf('%spx', KopaOptions::get_option('logo_margin_left', 0));
        $css['.kopa-logo']['margin-right'] = sprintf('%spx', KopaOptions::get_option('logo_margin_right', 0));


        /*
         * --------------------------------------------------
         * PRINT CUSTOMIZE RULES
         * --------------------------------------------------
         */
        $css = apply_filters('kopa_customize', $css);
        if (!empty($css)) {
            $out = '';
            foreach ($css as $element => $rules) {
                $tmp = '';
                foreach ($rules as $rule => $value) {
                    $tmp .= sprintf('%s : %s;', $rule, $value);
                }
                $out .= sprintf('%s{%s}', $element, $tmp);
            }
            printf('<style type="text/css">%s</style>', $out);
        }


        if ('#0088b2' != $primary_colors):
            ?>
            <style type="text/css">
                .kopa-main-nav ul.main-menu > li > a {
                    border-left-color: rgba(255, 255, 255, 0.3);
                    border-right-color: transparent !important;
                }

                .kopa-tab2-widget .nav-tabs>li.active>a, .kopa-tab2-widget .nav-tabs>li.active>a:hover, 
                .kopa-tab2-widget .nav-tabs>li.active>a:focus, .kopa-tab2-widget .nav-tabs>li:hover a, 
                .menu-owl-carousel .entry-content .entry-title a:hover {
                    color: <?php echo $primary_colors; ?> !important;
                }
                .kopa-owl-carousel-widget .owl-theme .owl-controls .owl-buttons .owl-prev:after, .sf-mega-section .widget-title  {
                    border-bottom-color: <?php echo $primary_colors; ?>;
                }
                .main-menu-mobile, 
                .element-tabs .nav-tabs>li.active>a:hover, .element-tabs .nav-tabs>li.active>a, .element-tabs .nav-tabs>li.active>a:focus, .element-tabs .nav-tabs>li:hover a, 
                ul.top-menu li ul, .kopa-owl-carousel-widget .owl-theme .owl-controls .owl-buttons .owl-next:after {
                    border-top-color: <?php echo $primary_colors; ?>;
                }
                
                .widget_categories ul li, .widget_rss ul li a, .widget_meta ul li,  
                .menu-owl-carousel .owl-buttons div, a:hover, .top-nav-mobile ul > li > a:hover, .top-nav-mobile ul li span, 
                .kopa-scrollbar-widget .item .entry-item .entry-content .entry-title a:hover, 
                .entry-date a, .entry-date span, .more-link, .kopa-owl-carousel-widget .entry-item header, 
                .kopa-owl-carousel-widget .entry-item header a, .bottom-sidebar a:hover, .footer-nav ul li a:hover, 
                .kopa-categories-list-widget .entry-title a:hover, .entry-price, 
                .kopa-product-list-widget .thumb-hover .fa:hover, .product-btn ul li > a:hover, 
                .article-list-3 .last-item .entry-title a:hover, .kopa-breadcrumb a:hover span, 
                .kopa-breadcrumb .current-page span, .entry-meta > p a, .entry-list-title, .entry-list-title a, 
                .video-hover a:hover, .kopa-video-slider .kopa-video-content .fa:hover, 
                .recent-title, #comments h4, #respond h4, .comments-list .comment .comment-wrap .media-body header h6, 
                .comments-list .comment .comment-wrap .media-body header .comment-button a, 
                .widget_archive ul li, .widget_nav_menu ul li, .widget_pages ul li, .widget_recent_comments ul li, 
                .post-date, .widget_recent_entries ul li .entry-date a, .widget_calendar thead th, .widget_calendar tbody a, 
                #contact-info address p a:hover, .error-404 .left-col p, .error-404 .right-col h1, .error-404 .right-col a:hover, 
                .kopa-pagelink a:hover, .arrow-list li, .kopa-main-nav ul.main-menu li .sub-menu a:hover, .tweetList li:before, .tweet_content_0 a{
                    color: <?php echo $primary_colors; ?>;
                } 

                .toggle-view li:hover span,.toggle-view li.active span, .sf-mega-section .widget-title, 
                .kopa-video-slider .kopa-video-content .fa:hover, li.mega-item > a, 
                .kopa-other-post .list-post-title span, 
                .kopa-owl-carousel-widget, .owl-carousel4 .owl-controls .owl-buttons div:hover, 
                #comments-form #comment_name:focus, #comments-form #comment_email:focus, #comments-form #comment_url:focus, 
                #comments-form #comment_message:focus,#contact-form #contact_name:focus, 
                #contact-form #contact_email:focus, #contact-form #contact_url:focus, #contact-form #contact_message:focus, 
                .contact-top .input-block input:focus, .textarea-block #comment_message:focus, #comments-form label.error,#contact-form label.error, 
                .kopa-single-slider .flex-direction-nav li a:hover, .green-button,.border-button:hover,
                .sf-mega-section > h2 > a, .flex-control-paging li a.flex-active, .flex-control-paging li a:hover, 
                #toggle-view li:hover span, #toggle-view li.active span, 
                a.kopa-social-link:hover {
                    border-color: <?php echo $primary_colors; ?>;
                }

                .kopa-tab-1-widget .dropdown-menu>li>a:hover, .kopa-tab-1-widget .dropdown-menu>li>a:focus, 
                .kopa-list-post-no-thumb .owl-theme .owl-controls .owl-buttons div, .owl-theme .owl-controls .owl-buttons div,
                .kopa-main-nav ul.main-menu, .element-tabs-2 .nav-tabs>li.active>a,.element-tabs-2 .nav-tabs>li.active>a:hover, .skill-rating > .pull-left, 
                .nav-tabs>li.active>a, .nav-tabs>li.active>a:hover, .nav-tabs>li.active>a:focus, .nav-tabs>li:hover a, 
                .wp-playlist-item.wp-playlist-playing:before,  
                .element-tabs-2 .nav-tabs>li.active>a:focus,.element-tabs-2 .nav-tabs>li:hover a,
                .kopa-blockquote:before, .toggle-view li:hover span,.toggle-view li.active span, .green-button,.border-button:hover, 
                .kopa-dropcap, .kopa-dropcap.color, .accordion-title.active span, .accordion-title span:hover,
                .kopa-single-slider .flex-direction-nav li a:hover, #contact-info address p i, 
                .tagcloud a:hover, #submit-comment,#submit-contact, .kopa-author >span, .social-filter > div > a, .social-filter ul li, 
                .kopa-tag-box ul li:hover, .kopa-video-carousel .flex-direction-nav a, .current-video-icon, 
                .owl-carousel4 .owl-controls .owl-buttons div:hover, .video-hover a, 
                .kopa-pagination ul li:hover, .kopa-pagination ul li.current, .recent-cat-post .last-item .entry-content, 
                .main-nav-mobile .pull, .widget-title, .kopa-list-post-no-thumb>span, 
                .kopa-list-post-no-thumb .owl-prev:before, .kopa-list-post-no-thumb .owl-next:before, 
                .entry-thumb .thumb-icon, .entry-thumb .icon-top, .entry-view span, .kopa-article-list-widget .entry-icon, 
                .kopa-categories-list-widget .entry-categories, .sale-icon, .progress-bar, #toggle-view li:hover span, #toggle-view li.active span, #back-top a:hover  {
                    background-color: <?php echo $primary_colors; ?>;
                }
            </style>
            <?php
        endif;


        /*
         * --------------------------------------------------
         * PRINT CUSTOMIZE CSS (from theme options)
         * --------------------------------------------------
         */
        $custom_css = htmlspecialchars_decode(stripslashes(KopaOptions::get_option('custom_css')));
        if ($custom_css) {
            printf('<style type="text/css">%s</style>', $custom_css);
        }
    }

    /**
     * Enqueue customize scripts (or style) for frontend
     *
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0
     * 
     * @param string
     * @return NULl
     */
    function enqueue_scripts() {
        wp_localize_script(KOPA_OPT_PREFIX . 'custom', 'kopa_variable_fonts', $this->load_font());
    }

    /**
     * Enqueue customize scripts (or style) for backend
     *
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0
     * 
     * @param string
     * @return NULl
     */
    function theme_options_enqueue($hook) {
        if ('toplevel_page_kopa_cpanel_theme_options' == $hook) {
            $this->load_font();
        }
    }

    /**
     * Enqueue custom font - selected by admin
     *
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0
     *      
     * @return NULl
     */
    function load_font() {
        global $google_font;

        $front_font = array(
            'Roboto:400,500,700',
            'Open+Sans:300,400,600,700,800'
        );

        $typos = kopa_options_typography();
        foreach ($typos as $group) {
            foreach ($group['fields'] as $field) {
                if ('font' == $field['type']) {
                    $value = KopaOptions::get_option($field['name'], $field['default']);
                    if (isset($value) || !empty($value)) {
                        if ('off' != $value['family']) {
                            $font_family = str_replace(' ', '+', $google_font['items'][$value['family']]['family']);
                            $cssID = sprintf('css-dynamic-%s-family', $field['name']);
                            $tmp = sprintf('http://fonts.googleapis.com/css?family=%s:%s', $font_family, $value['weight']);

                            if (is_admin()) {
                                wp_enqueue_style($cssID, $tmp, array(), NULL);
                            } else {
                                $front_font[] = sprintf('%s:%s', $font_family, $value['weight']);
                            }
                            $this->typography[$field['name']] = $value;
                            $this->typography[$field['name']]['family'] = $google_font['items'][$value['family']]['family'];
                        }
                    }
                }
            }
        }

        return $front_font;
    }

}
