<?php
add_action('after_setup_theme', 'kopa_front_after_setup_theme');

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_front_after_setup_theme() {

    add_theme_support('post-formats', array('gallery', 'audio', 'video'));
    add_theme_support('post-thumbnails');
    add_theme_support('loop-pagination');
    add_theme_support('automatic-feed-links');
    add_theme_support('editor_style');
    add_editor_style('editor-style.css');

    global $content_width;
    if (!isset($content_width))
        $content_width = 700;
    register_nav_menus(array(
        'top-nav' => __('Top Menu', kopa_get_domain()),
        'main-nav' => __('Main Menu', kopa_get_domain()),
        'footer-nav' => __('Footer Menu', kopa_get_domain()),
    ));

    if (!is_admin()) {
        add_action('wp_enqueue_scripts', 'kopa_front_enqueue_scripts');
        add_action('wp_head', 'kopa_head');
        add_filter('widget_text', 'do_shortcode');
        add_filter('post_class', 'kopa_post_class');
        add_filter('body_class', 'kopa_body_class');
        add_filter('wp_nav_menu_items', 'kopa_add_home_menuitem', 10, 2);
        add_action('pre_get_posts', 'kopa_edit_archive_query');
        add_filter('kopa_blog_is_display_blog_post_format', 'kopa_blog_is_display_blog_post_format');
        add_filter('language_attributes', 'kopa_add_open_graph_xml_nameservers');
    }
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_add_open_graph_xml_nameservers($doctype) {
    if ('true' == KopaOptions::get_option('seo_status', 'false')) {
        $nameservers = array();
        $nameservers[] = 'xmlns="http://www.w3.org/1999/xhtml"';
        $nameservers[] = 'xmlns:og="http://ogp.me/ns#"';
        $nameservers[] = 'xmlns:fb="http://www.facebook.com/2008/fbml"';
        $doctype.= sprintf(' %s ', implode(' ', $nameservers));
    }
    return $doctype;
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_blog_is_display_blog_post_format($is_display) {
    global $wp_query;
    $private_is_display = 'inherit';
    if (!is_admin() && $wp_query->is_main_query()) {
        if (is_tag() || is_category()) {
            $id = get_queried_object_id();
            $key = sprintf('%s%s_%s', KOPA_OPT_PREFIX, 'is_display_content_formatted', $id);
            $private_is_display = get_option($key, 'inherit');
        }
    }
    if ('inherit' != $private_is_display) {
        $is_display = $private_is_display;
    }
    return filter_var($is_display, FILTER_VALIDATE_BOOLEAN);
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_edit_archive_query($query) {
    if (!is_admin() && $query->is_main_query()) {
        $post_per_page = 'inherit';
        if (is_tag()) {
            $slug = $query->query_vars['tag'];
            $tag = get_term_by('slug', $slug, 'post_tag');
            if (!empty($tag)) {
                $post_per_page = get_option(KOPA_OPT_PREFIX . 'posts_per_page_' . $tag->term_id, 'inherit');
            }
        } else if (is_category()) {
            $slug = $query->query_vars['category_name'];
            $cat = get_term_by('slug', $slug, 'category');
            if (!empty($cat)) {
                $post_per_page = get_option(KOPA_OPT_PREFIX . 'posts_per_page_' . $cat->term_id, 'inherit');
            }
        }
        if ('inherit' != $post_per_page) {
            switch ($post_per_page) {
                case '-1':
                    $query->query_vars['posts_per_page'] = -1;
                    break;
                default:
                    $query->query_vars['posts_per_page'] = (int) $post_per_page;
                    break;
            }
        }
    }
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_add_home_menuitem($items, $args) {
    if ('primary-nav' == $args->theme_location && 'main-menu' == $args->menu_id) {
        $home_html = sprintf('<li class="home-menu-icon"><a class="icon-home" href="%s" title="%s"></a></li>', home_url(), __('Home', kopa_get_domain()));
        $items = $home_html . $items;
    }
    return $items;
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_post_class($classes) {
    return $classes;
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_body_class($classes) {
    $kopa_layout = KopaInit::get_layouts();
    $kopaCurrentSetting = KopaLayout::get_current_setting();
    $kopaCurrentLayout = $kopaCurrentSetting['layout_slug'];
    $kopaCurrentSidebars = $kopaCurrentSetting['sidebars'][$kopaCurrentLayout];
    $classes[] = "kopa-layout-{$kopaCurrentLayout}";
    $positions = $kopa_layout[$kopaCurrentLayout]['positions'];
    foreach ($positions as $index => $position) {
        if (!is_active_sidebar($kopaCurrentSidebars[$index])) {
            $classes[] = "kopa-hide-{$position}";
        } else {
            $classes[] = "kopa-show-{$position}";
        }
    }
    return $classes;
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_head() {
    /**
     * FAVICON
     */
    $favicon = KopaOptions::get_option('favicon');
    if ($favicon) {
        printf('<link rel="shortcut icon" type="image/x-icon"  href="%s">', do_shortcode($favicon));
    }
    /**
     * APPLE ICON
     */
    $apple_icon = KopaOptions::get_option('apple_icon');
    if ($apple_icon) {
        $apple_icon = do_shortcode($apple_icon);
        foreach (array(60, 76, 120, 152) as $size) {
            $tmp = bfi_thumb($apple_icon, array('width' => $size, 'height' => $size, 'crop' => true));
            printf('<link rel="apple-touch-icon" sizes="%1$sx%1$s" href="%2$s">', $size, $tmp);
        }
    }
}


/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_front_enqueue_scripts() {
    if (!is_admin()) {
        global $wp_styles, $is_IE, $kopaCurrentLayout;
        $dir = get_template_directory_uri();
        /*
         * --------------------------------------------------
         * STYLESHEETS    
         * --------------------------------------------------
         */
        
        wp_enqueue_style(KOPA_OPT_PREFIX . 'font-awesome', "{$dir}/library/assets/fonts/awesome/css/font-awesome.css");
        wp_enqueue_style(KOPA_OPT_PREFIX . 'bootstrap', $dir . '/css/bootstrap.min.css', array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'magnific-popup', $dir . '/css/magnific-popup.css', array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'mega-fish', $dir . '/css/megafish.css', array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'mega-menu', $dir . '/css/mega-menu.css', array(), NULL);        
        wp_enqueue_style(KOPA_OPT_PREFIX . 'flexslider', $dir . '/css/flexslider.css', array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'owl-carousel', $dir . '/css/owl.carousel.css', array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'owl-theme', $dir . '/css/owl.theme.css', array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'jquery-fotorama', $dir . '/css/fotorama.css', array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'jquery-mCustomScrollbar', $dir . '/css/jquery.mCustomScrollbar.css', array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'style', get_stylesheet_uri(), array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'extra', $dir. '/css/extra.css', array(), NULL);
        wp_enqueue_style(KOPA_OPT_PREFIX . 'responsive', $dir . '/css/responsive.css', array(KOPA_OPT_PREFIX . 'style'), NULL);
        /*
         * --------------------------------------------------
         * SCRIPTS    
         * --------------------------------------------------
         */
        wp_enqueue_script('jquery');
        wp_enqueue_script('jquery-form');

        if ('contact-page' == $kopaCurrentLayout)
            wp_enqueue_script(KOPA_OPT_PREFIX . 'maps-api', 'http://maps.google.com/maps/api/js?sensor=true', array('jquery'), NULL, TRUE);

        if (is_singular())
            wp_enqueue_script('comment-reply');

        wp_enqueue_script(KOPA_OPT_PREFIX . 'bootstrap', $dir . '/js/bootstrap.min.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script(KOPA_OPT_PREFIX . 'modernizr', $dir . '/js/modernizr.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script(KOPA_OPT_PREFIX . 'jquery-fotorama', $dir . '/js/fotorama.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script(KOPA_OPT_PREFIX . 'custom', $dir . '/js/custom.js', array('jquery'), NULL, TRUE);
        wp_localize_script(KOPA_OPT_PREFIX . 'custom', 'kopa_variable', kopa_variable_front());
        /*
         * --------------------------------------------------
         * IE FIX
         * --------------------------------------------------
         */
        if ($is_IE) {
            wp_register_style(KOPA_OPT_PREFIX . 'ie', $dir . '/css/ie.css', array(), NULL);
            wp_enqueue_style(KOPA_OPT_PREFIX . 'ie');
            $wp_styles->add_data(KOPA_OPT_PREFIX . 'ie', 'conditional', 'lt IE 9');

            wp_enqueue_script(KOPA_OPT_PREFIX . 'html5', 'https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js', array(), NULL, TRUE);
            wp_enqueue_script(KOPA_OPT_PREFIX . 'respond', 'https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js', array(), NULL, TRUE);
            wp_enqueue_script(KOPA_OPT_PREFIX . 'pie', $dir . '/js/PIE_IE678.js', array(), NULL, TRUE);
        }
    }
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_variable_front() {
    return array(
        'url' => array(
            'template_directory_uri' => get_template_directory_uri(),
            'ajax' => admin_url('admin-ajax.php')
        ),
        'template' => array(
            'post_id' => (is_singular()) ? get_queried_object_id() : 0
        ),
        'contact' => array(
            'address' => KopaOptions::get_option('contact_address', ''),
            'marker' => do_shortcode(KopaOptions::get_option('contact_map_marker', '')),
        ),
        'i18n' => array(
            'SEARCH' => __('Search...', kopa_get_domain()),
            'LOADING' => __('Loading...', kopa_get_domain()),
            'LOAD_MORE' => __('Load more', kopa_get_domain()),
            'LOADING' => __('Loading...', kopa_get_domain()),
            'VIEW' => __('View', kopa_get_domain()),
            'VIEWS' => __('Views', kopa_get_domain()),
            'validate' => array(
                'form' => array(
                    'CHECKING' => __('Checking', kopa_get_domain()),
                    'SUBMIT' => __('Submit', kopa_get_domain()),
                    'SENDING' => __('Sending...', kopa_get_domain())
                ),
                'recaptcha' => array(
                    'INVALID' => __('Your captcha is incorrect. Please try again', kopa_get_domain()),
                    'REQUIRED' => __('Captcha is required', kopa_get_domain())
                ),
                'name' => array(
                    'REQUIRED' => __('Please enter your name', kopa_get_domain()),
                    'MINLENGTH' => __('At least {0} characters required', kopa_get_domain())
                ),
                'email' => array(
                    'REQUIRED' => __('Please enter your email', kopa_get_domain()),
                    'EMAIL' => __('Please enter a valid email', kopa_get_domain())
                ),
                'url' => array(
                    'REQUIRED' => __('Please enter your url', kopa_get_domain()),
                    'URL' => __('Please enter a valid url', kopa_get_domain())
                ),
                'message' => array(
                    'REQUIRED' => __('Please enter a message', kopa_get_domain()),
                    'MINLENGTH' => __('At least {0} characters required', kopa_get_domain())
                )
            )
        )
    );
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_get_headline() {
    $limit = (int) KopaOptions::get_option('headline_limit', 4);
    if ($limit) {
        $cats = KopaOptions::get_option('headline_cats');
        $tags = KopaOptions::get_option('headline_tags');
        $formats = KopaOptions::get_option('headline_formats');
        $timestamp = KopaOptions::get_option('headline_timestamp');
        $query = array(
            'post_type' => array('post'),
            'posts_per_page' => $limit,
            'post_status' => array('publish'),
            'ignore_sticky_posts' => true
        );
        if (!empty($cats)) {
            $query['tax_query'][] = array(
                'taxonomy' => 'category',
                'field' => 'id',
                'terms' => $cats
            );
        }
        if (!empty($tags)) {
            $query['tax_query'][] = array(
                'taxonomy' => 'post_tag',
                'field' => 'id',
                'terms' => $tags
            );
        }
        if (!empty($formats)) {
            $query['tax_query'][] = array(
                'taxonomy' => 'post_format',
                'field' => 'id',
                'terms' => $formats
            );
        }
        if (isset($query['tax_query']) && (count($query['tax_query']) >= 2)) {
            $query['tax_query']['relation'] = ('true' == KopaOptions::get_option('headline_relation')) ? 'AND' : 'OR';
        }
        global $wp_version;
        if (version_compare($wp_version, '3.7.0', '>=')) {
            if (isset($timestamp) && !empty($timestamp)) {
                $y = date('Y', strtotime($timestamp));
                $m = date('m', strtotime($timestamp));
                $d = date('d', strtotime($timestamp));
                $query['date_query'] = array(
                    array(
                        'after' => array(
                            'year' => (int) $y,
                            'month' => (int) $m,
                            'day' => (int) $d
                        )
                    )
                );
            }
        }
        $posts = new WP_Query($query);
        if ($posts->have_posts()) {
            $label_line_1 = KopaOptions::get_option('headline_label_line_1');
            $label_line_2 = KopaOptions::get_option('headline_label_line_2');
            ?>

            <div class="widget kopa-list-post-no-thumb clearfix">
                <span></span>

                <h3 class="widget-title"><?php echo $label_line_1; ?><span><?php echo $label_line_2; ?></span></h3>

                <div class="list-post-main">
                    <div class="owl-carousel owl-carousel1"> 
                        <?php
                        while ($posts->have_posts()) {
                            $posts->the_post();
                            $post_url = get_permalink();
                            $post_title = get_the_title();
                            ?>
                            <div class="item">
                                <article class="entry-item clearfix">
                                    <?php if ( ! empty($post_title) ) : ?>
                                        <h4 class="entry-title"><a href="<?php echo $post_url; ?>"><?php echo $post_title; ?></a></h4>
                                    <?php endif; ?>
                                    <span class="entry-date"><?php echo get_the_date(); ?></span>
                                </article>  
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                </div>
            </div><!--/end widget.kopa-list-post-no-thumb-->
            <?php
        }
        wp_reset_postdata();
    }
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_get_related_posts() {
    if (is_single()) {
        $get_by = get_option('post_related_posts_get_by', 'post_tag');
        $limit = (int) KopaOptions::get_option('post_related_posts_limit', 4);
        if ($limit > 0) {
            global $post;
            $taxs = array();
            if ('category' == $get_by) {
                $cats = get_the_category(($post->ID));
                if ($cats) {
                    $ids = array();
                    foreach ($cats as $cat) {
                        $ids[] = $cat->term_id;
                    }
                    $taxs [] = array(
                        'taxonomy' => 'category',
                        'field' => 'id',
                        'terms' => $ids
                    );
                }
            } else {
                $tags = get_the_tags($post->ID);
                if ($tags) {
                    $ids = array();
                    foreach ($tags as $tag) {
                        $ids[] = $tag->term_id;
                    }
                    $taxs [] = array(
                        'taxonomy' => 'post_tag',
                        'field' => 'id',
                        'terms' => $ids
                    );
                }
            }
            if ($taxs) {
                $related_args = array(
                    'tax_query' => $taxs,
                    'post__not_in' => array($post->ID),
                    'posts_per_page' => $limit
                );
                $related_posts = new WP_Query($related_args);
                if ($related_posts->have_posts()):
                    ?>            
                    <div class="kopa-recent-post">
                        <h3 class="recent-title"><?php _e('Related articles', kopa_get_domain()); ?></h3>
                        <ul class="clearfix">
                            <?php
                            while ($related_posts->have_posts()):
                                $related_posts->the_post();
                                $post_url = get_permalink();
                                $post_title = get_the_title();
                                ?>

                                <li>
                                    <article class="entry-item">
                                        <div class="entry-content">
                                            <header>
                                                <?php if ( ! empty($post_title) ) : ?>
                                                    <h4 class="entry-title"><a href="<?php echo $post_url; ?>" title="<?php echo $post_title; ?>"><?php echo $post_title; ?></a></h4>
                                                <?php endif; ?>
                                                <p class="entry-date"><?php _e('Posted:', kopa_get_domain()); ?><span><?php echo get_the_date(); ?></span></p>
                                            </header>
                                            <?php
                                            if (has_excerpt()) {
                                                printf('<p>%s</p>', get_the_excerpt());
                                            } else {
                                                global $post;
                                                if ($break_point = strpos($post->post_content, '<!--more-->')) {
                                                    printf('<p>%s</p>', substr($post->post_content, 0, $break_point));
                                                } else {
                                                    printf('<p>%s</p>', get_the_excerpt());
                                                }
                                            }
                                            ?>
                                        </div>
                                    </article>
                                </li>
                                <?php
                            endwhile;
                            ?>
                        </ul>
                    </div>                    
                    <?php
                endif;
                wp_reset_postdata();
            }
        }
    }
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_get_about_author() {
    if ('true' == KopaOptions::get_option('is_display_post_author_information', 'true')) {
        global $post;
        $user_id = $post->post_author;
        $description = get_the_author_meta('description', $user_id);
        $email = get_the_author_meta('user_email', $user_id);
        $name = get_the_author_meta('display_name', $user_id);
        $url = trim(get_the_author_meta('user_url', $user_id));
        $link = ($url) ? $url : get_author_posts_url($user_id);
        $jobs = get_the_author_meta('jobs', $user_id);
        ?>
        <div class="kopa-author clearfix">
            <span></span>

            <a class="avatar-thumb" href="<?php echo $link; ?>" title="<?php echo $name; ?>"><?php echo get_avatar($email, 91); ?></a> 

            <div class="author-content media-body">
                <div class="author-social-link">
                    <div class="kopa-relative">

                        <?php if ('true' == KopaOptions::get_option('is_display_post_author_social_links', 'true')): ?>                        

                            <?php
                            $socials = array('facebook', 'twitter', 'dribbble', 'flickr', 'pinterest', 'google_plus');
                            $social_links = array();
                            foreach ($socials as $social) {
                                $tmp = get_the_author_meta($social, $user_id);
                                if ($tmp) {
                                    $social_links[$social] = $tmp;
                                }
                            }
                            if (!empty($social_links)):
                                ?>
                                <span><?php _e('Follow me on:', kopa_get_domain()); ?></span>

                                <div class="social-filter clearfix">
                                    <?php
                                    $is_first = true;
                                    foreach ($social_links as $type => $url):
                                        $type = str_replace('_', '-', $type);

                                        if ($is_first):
                                            ?>
                                            <div class="clearfix">
                                                <a href="<?php echo $url; ?>" title="<?php printf(__('Follow author %s on %s', kopa_get_domain()), $name, $type); ?>" class="fa <?php echo "fa-{$type}"; ?>"></a>
                                                <span class="fa fa-sort-asc"></span>
                                            </div>
                                            <ul>
                                                <?php
                                            else:
                                                ?>
                                                <li><a href="<?php echo $url; ?>" title="<?php printf(__('Follow author %s on %s', kopa_get_domain()), $name, $type); ?>" class="fa <?php echo "fa-{$type}"; ?>"></a></li>
                                            <?php
                                            endif;
                                            $is_first = false;
                                        endforeach;
                                        ?>
                                    </ul>                                   
                                </div>
                            <?php endif; ?>
                        <?php endif; ?>

                    </div>
                </div>

                <header class="clearfix">
                    <div class="pull-left">
                        <h5 class="author-name"><a href="<?php echo $link; ?>" title="<?php echo $name; ?>"><?php echo $name; ?></a></h5>
                        <?php if ($jobs): ?>
                            <span class="author-job"><?php echo $jobs; ?></span>
                        <?php endif; ?>
                    </div>
                </header>

                <?php echo ($description) ? "<p>{$description}</p>" : ''; ?>

            </div>

        </div>
        <?php
    }
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_get_social_links() {
    $social_links = KopaInit::get_social_icons();
    ?>
    <ul id="header-social-links">
        <?php
        foreach ($social_links as $slug => $info) {
            $href = KopaOptions::get_option("social_link_{$slug}");
            if ('rss' == $slug) {
                if (empty($href)) {
                    $href = get_bloginfo_rss('rss2_url');
                } elseif ('HIDE' == $href) {
                    $href = '';
                }
            }
            if (!empty($href)) {
                printf('<li><a class="kopa-social-link" href="%s" target="_blank" title="%s" rel="nofollow"><i class="%s"></i></a></li>', $href, $info['title'], $info['icon']);
            }
        }
        ?>
    </ul>
    <?php
}
