<?php

add_action('init', 'kopa_init_database');

class KopaInit {

    /**
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0         
     */
    static function get_positions() {
        $positions = array();
        $positions['position_1'] = array('title' => __('Widget Area 1', kopa_get_domain()));
        $positions['position_5'] = array('title' => __('Widget Area 5', kopa_get_domain()));
        $positions['position_6'] = array('title' => __('Widget Area 6', kopa_get_domain()));
        $positions['position_7'] = array('title' => __('Widget Area 7', kopa_get_domain()));
        $positions['position_8'] = array('title' => __('Widget Area 8', kopa_get_domain()));
        $positions['position_9'] = array('title' => __('Widget Area 9', kopa_get_domain()));
        $positions['position_10'] = array('title' => __('Widget Area 10', kopa_get_domain()));

        return apply_filters('kopa_init_get_positions', $positions);
    }

    /**
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0         
     */
    static function get_layouts() {
        $layouts = array();

        $layouts['blog-page-1'] = array(
            'title' => __('Blog Page 1', kopa_get_domain()),
            'slug' => 'blog-page-1',
            'positions' => array(
                'position_5',
                'position_7',
                'position_8',
                'position_9',
                'position_10'
            )
        );

        $layouts['single-post-1'] = array(
            'title' => __('Single Post 1', kopa_get_domain()),
            'slug' => 'single-post-1',
            'positions' => array(
                'position_5',
                'position_7',
                'position_8',
                'position_9',
                'position_10'
            )
        );
        $layouts['single-post-2'] = array(
            'title' => __('Single Post 2', kopa_get_domain()),
            'slug' => 'single-post-2',
            'positions' => array(
                'position_5',
                'position_7',
                'position_8',
                'position_9',
                'position_10'
            )
        );


        $layouts['static-page-1'] = array(
            'title' => __('Static Page (Fullwidth)', kopa_get_domain()),
            'slug' => 'static-page-1',
            'positions' => array(
                'position_7',
                'position_8',
                'position_9',
                'position_10'
            )
        );

        $layouts['static-page-2'] = array(
            'title' => __('Static Page (Right Sidebar)', kopa_get_domain()),
            'slug' => 'static-page-2',
            'positions' => array(
                'position_5',
                'position_7',
                'position_8',
                'position_9',
                'position_10'
            )
        );

        $layouts['contact-page'] = array(
            'title' => __('Contact Page', kopa_get_domain()),
            'slug' => 'contact-page',
            'positions' => array(
                'position_7',
                'position_8',
                'position_9',
                'position_10'
            )
        );

        $layouts['media-page'] = array(
            'title' => __('Media Page', kopa_get_domain()),
            'slug' => 'media-page',
            'positions' => array(
                'position_1',
                'position_6',
                'position_7',
                'position_8',
                'position_9',
                'position_10'
            )
        );

        $layouts['static-page-timeline'] = array(
            'title' => __('Static Page - Timeline', kopa_get_domain()),
            'slug' => 'static-page-timeline',
            'positions' => array(
            )
        );

        $layouts['error-404'] = array(
            'title' => __('Error 404', kopa_get_domain()),
            'slug' => 'error-404',
            'positions' => array(
                'position_7',
                'position_8',
                'position_9',
                'position_10'
            )
        );
        return apply_filters('kopa_init_get_layouts', $layouts);
    }

    /**
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0         
     */
    static function get_sidebars() {
        $sidebars = array();
        $sidebars['sidebar_hide'] = __('-- None --', kopa_get_domain());
        $sidebars['sidebar_5'] = __('Right', kopa_get_domain());
        $sidebars['sidebar_7'] = __('Footer 1', kopa_get_domain());
        $sidebars['sidebar_8'] = __('Footer 2', kopa_get_domain());
        $sidebars['sidebar_9'] = __('Footer 3', kopa_get_domain());
        $sidebars['sidebar_10'] = __('Footer 4', kopa_get_domain());
        $sidebars['sidebar_15'] = __('Media - Top', kopa_get_domain());
        $sidebars['sidebar_16'] = __('Media - Bottom', kopa_get_domain());


        return apply_filters('kopa_init_get_sidebars', $sidebars);
    }

    /**
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0         
     */
    static function get_template_hierarchy() {
        $template = array();
        $template['home'] = array(
            'icon' => 'dashicons dashicons-admin-home',
            'title' => __('Home', kopa_get_domain()),
            'layouts' => array(
                'blog-page-1'
            )
        );
        $template['post'] = array(
            'icon' => 'dashicons dashicons-admin-post',
            'title' => __('Single Post', kopa_get_domain()),
            'layouts' => array(
                'single-post-1',
                'single-post-2'
            )
        );
        $template['page'] = array(
            'icon' => 'dashicons dashicons-admin-page',
            'title' => __('Static Page', kopa_get_domain()),
            'layouts' => array(
                'static-page-1',
                'static-page-2',
                'contact-page',
                'media-page'
            )
        );
        $template['archive'] = array(
            'icon' => 'dashicons dashicons-images-alt',
            'title' => __('Archive', kopa_get_domain()),
            'layouts' => array(
                'blog-page-1'
            )
        );
        $template['taxonomy'] = array(
            'icon' => 'dashicons dashicons-tag',
            'title' => __('Category | Tag', kopa_get_domain()),
            'layouts' => array(
                'blog-page-1'
            )
        );
        $template['author'] = array(
            'icon' => 'dashicons dashicons-businessman',
            'title' => __('Author', kopa_get_domain()),
            'layouts' => array(
                'blog-page-1'
            )
        );
        $template['search'] = array(
            'icon' => 'dashicons dashicons-search',
            'title' => __('Search Result', kopa_get_domain()),
            'layouts' => array(
                'blog-page-1'
            )
        );
        $template['_404'] = array(
            'icon' => 'dashicons dashicons-sos',
            'title' => __('404 Page not found', kopa_get_domain()),
            'layouts' => array(
                'error-404'
            )
        );
        return apply_filters('kopa_init_get_template_hierarchy', $template);
    }

    /**
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0         
     */
    static function get_social_icons() {
        $socials = array();

        $socials['facebook'] = array(
            'title' => __('Facebook', kopa_get_domain()),
            'icon' => 'fa fa-facebook',
            'color' => ''
        );
        $socials['dribbble'] = array(
            'title' => __('Dribbble', kopa_get_domain()),
            'icon' => 'fa fa-dribbble',
            'color' => ''
        );
        $socials['linkedin'] = array(
            'title' => __('Linkedin', kopa_get_domain()),
            'icon' => 'fa fa-linkedin',
            'color' => ''
        );
        $socials['pinterest'] = array(
            'title' => __('Pinterest', kopa_get_domain()),
            'icon' => 'fa fa-pinterest',
            'color' => ''
        );
        $socials['google-plus'] = array(
            'title' => __('Google plus', kopa_get_domain()),
            'icon' => 'fa fa-google-plus',
            'color' => ''
        );
        $socials['twitter'] = array(
            'title' => __('Twitter', kopa_get_domain()),
            'icon' => 'fa fa-twitter',
            'color' => ''
        );
        $socials['adn'] = array(
            'title' => __('Adn', kopa_get_domain()),
            'icon' => 'fa fa-adn',
            'color' => ''
        );
        $socials['android'] = array(
            'title' => __('Android', kopa_get_domain()),
            'icon' => 'fa fa-android',
            'color' => ''
        );
        $socials['apple'] = array(
            'title' => __('Apple', kopa_get_domain()),
            'icon' => 'fa fa-apple',
            'color' => ''
        );
        $socials['bitbucket'] = array(
            'title' => __('Bitbucket', kopa_get_domain()),
            'icon' => 'fa fa-bitbucket',
            'color' => ''
        );
        $socials['btc'] = array(
            'title' => __('Btc', kopa_get_domain()),
            'icon' => 'fa fa-btc',
            'color' => ''
        );
        $socials['css3'] = array(
            'title' => __('Css3', kopa_get_domain()),
            'icon' => 'fa fa-css3',
            'color' => ''
        );
        $socials['dropbox'] = array(
            'title' => __('Dropbox', kopa_get_domain()),
            'icon' => 'fa fa-dropbox',
            'color' => ''
        );
        $socials['flickr'] = array(
            'title' => __('Flickr', kopa_get_domain()),
            'icon' => 'fa fa-flickr',
            'color' => ''
        );
        $socials['foursquare'] = array(
            'title' => __('Foursquare', kopa_get_domain()),
            'icon' => 'fa fa-foursquare',
            'color' => ''
        );
        $socials['github'] = array(
            'title' => __('Github', kopa_get_domain()),
            'icon' => 'fa fa-github',
            'color' => ''
        );
        $socials['gittip'] = array(
            'title' => __('Gittip', kopa_get_domain()),
            'icon' => 'fa fa-gittip',
            'color' => ''
        );
        $socials['html5'] = array(
            'title' => __('Html5', kopa_get_domain()),
            'icon' => 'fa fa-html5',
            'color' => ''
        );
        $socials['instagram'] = array(
            'title' => __('Instagram', kopa_get_domain()),
            'icon' => 'fa fa-instagram',
            'color' => ''
        );
        $socials['linux'] = array(
            'title' => __('Linux', kopa_get_domain()),
            'icon' => 'fa fa-linux',
            'color' => ''
        );
        $socials['pagelines'] = array(
            'title' => __('Pagelines', kopa_get_domain()),
            'icon' => 'fa fa-pagelines',
            'color' => ''
        );
        $socials['maxcdn'] = array(
            'title' => __('Maxcdn', kopa_get_domain()),
            'icon' => 'fa fa-maxcdn',
            'color' => ''
        );
        $socials['renren'] = array(
            'title' => __('Renren', kopa_get_domain()),
            'icon' => 'fa fa-renren',
            'color' => ''
        );
        $socials['skype'] = array(
            'title' => __('Skype', kopa_get_domain()),
            'icon' => 'fa fa-skype',
            'color' => ''
        );
        $socials['stack-exchange'] = array(
            'title' => __('Stack exchange', kopa_get_domain()),
            'icon' => 'fa fa-stack-exchange',
            'color' => ''
        );
        $socials['stack-overflow'] = array(
            'title' => __('Stack overflow', kopa_get_domain()),
            'icon' => 'fa fa-stack-overflow',
            'color' => ''
        );
        $socials['trello'] = array(
            'title' => __('Trello', kopa_get_domain()),
            'icon' => 'fa fa-trello',
            'color' => ''
        );
        $socials['tumblr'] = array(
            'title' => __('Tumblr', kopa_get_domain()),
            'icon' => 'fa fa-tumblr',
            'color' => ''
        );
        $socials['vk'] = array(
            'title' => __('vk', kopa_get_domain()),
            'icon' => 'fa fa-vk',
            'color' => ''
        );
        $socials['weibo'] = array(
            'title' => __('Weibo', kopa_get_domain()),
            'icon' => 'fa fa-weibo',
            'color' => ''
        );
        $socials['windows'] = array(
            'title' => __('Windows', kopa_get_domain()),
            'icon' => 'fa fa-windows',
            'color' => ''
        );
        $socials['xing'] = array(
            'title' => __('Xing', kopa_get_domain()),
            'icon' => 'fa fa-xing',
            'color' => ''
        );
        $socials['youtube'] = array(
            'title' => __('Youtube', kopa_get_domain()),
            'icon' => 'fa fa-youtube',
            'color' => ''
        );
        $socials['rss'] = array(
            'title' => __('RSS', kopa_get_domain()),
            'icon' => 'fa fa-rss',
            'color' => '',
            'help' => __('Display the RSS feed button with the default RSS feed or enter a custom feed above. <br/>Enter <code>HIDE</code> if you want to hide it', kopa_get_domain())
        );
        return apply_filters('kopa_init_get_social_icons', $socials);
    }

    /**
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0         
     */
    static function get_image_sizes() {
        $sizes = array();
        // posts tabs by group
        $sizes['size_02'] = array(
            'name' => __('247 x 169 (pixel)', kopa_get_domain()),
            'width' => 247,
            'height' => 169,
            'crop' => true,
            'desc' => __('Widget: Post tabs by group', kopa_get_domain()),
            'type' => array('post')
        );

        // widget: kopa gallery (small)
        // widget: video grid
        $sizes['size_10'] = array(
            'name' => __('284 x 164 (pixel)', kopa_get_domain()),
            'width' => 284,
            'height' => 164,
            'crop' => true,
            'desc' => __('Widget: Gallery (small)', kopa_get_domain()),
            'type' => array('post')
        );

        // archive 1
        $sizes['size_14'] = array(
            'name' => __('719 x 400 (pixel)', kopa_get_domain()),
            'width' => 719,
            'height' => 400,
            'crop' => true,
            'desc' => __('Layout: Blog page 1', kopa_get_domain()),
            'type' => array('post')
        );

        // widget: posts video (hightlight)
        $sizes['size_17'] = array(
            'name' => __('530 x 384 (pixel)', kopa_get_domain()),
            'width' => 530,
            'height' => 384,
            'crop' => true,
            'desc' => __('Widget: Posts video (hightlight)', kopa_get_domain()),
            'type' => array('post')
        );

        return apply_filters('kopa_init_get_image_sizes', $sizes);
    }

    /**
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0         
     */
    static function get_sidebar_args() {
        $args = array(
            'before_widget' => '<div id="%1$s" class="widget %2$s clearfix">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        );
        return apply_filters('kopa_ini_get_sidebar_args', $args);
    }

    /**
     * @package Kopa
     * @subpackage Core
     * @author thethangtran <tranthethang@gmail.com>
     * @since 1.0.0         
     */
    static function get_theme_option_fields() {
        $tabs = array();
        $tabs['general-setting'] = array(
            'title' => __('General Setting', kopa_get_domain()),
            'groups' => kopa_options_general(),
            'icon' => 'fa fa-gear'
        );
        $tabs['blog-posts'] = array(
            'title' => __('Blog Posts', kopa_get_domain()),
            'groups' => kopa_options_blog_posts(),
            'icon' => 'fa fa-folder-open-o'
        );
        $tabs['single-post'] = array(
            'title' => __('Single Post', kopa_get_domain()),
            'groups' => kopa_options_single_post(),
            'icon' => 'fa fa-file-text-o'
        );
        $tabs['contact'] = array(
            'title' => __('Contact', kopa_get_domain()),
            'groups' => kopa_options_contact(),
            'icon' => 'fa fa-envelope-o'
        );
        return $tabs;
    }

}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0         
 */
function kopa_init_database() {
    $kopa_is_database_setup = get_option(KOPA_OPT_PREFIX . 'database_setup');
    if ($kopa_is_database_setup !== KOPA_INIT_VERSION) {
        $kopa_setting = array(
            'home' => array(
                'layout_slug' => 'blog-page-1',
                'sidebars' => array(
                    'blog-page-1' => array(
                        'sidebar_5',
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10',
                    )
                )
            ),
            'post' => array(
                'layout_slug' => 'single-post-1',
                'sidebars' => array(
                    'single-post-1' => array(
                        'sidebar_5',
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10'
                    ),
                    'single-post-2' => array(
                        'sidebar_5',
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10'
                    )
                ),
            ),
            'page' => array(
                'layout_slug' => 'static-page-1',
                'sidebars' => array(
                    'static-page-1' => array(
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10'
                    ),
                    'static-page-2' => array(
                        'sidebar_5',
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10'
                    ),
                    'contact-page' => array(
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10'
                    ),
                    'media-page' => array(
                        'sidebar_15',
                        'sidebar_16',
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10'
                    )
                )
            ),
            'taxonomy' => array(
                'layout_slug' => 'blog-page-1',
                'sidebars' => array(
                    'blog-page-1' => array(
                        'sidebar_5',
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10',
                    )
                )
            ),
            'author' => array(
                'layout_slug' => 'blog-page-1',
                'sidebars' => array(
                    'blog-page-1' => array(
                        'sidebar_5',
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10',
                    )
                )
            ),
            'search' => array(
                'layout_slug' => 'blog-page-1',
                'sidebars' => array(
                    'blog-page-1' => array(
                        'sidebar_5',
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10',
                    )
                )
            ),
            'archive' => array(
                'layout_slug' => 'blog-page-1',
                'sidebars' => array(
                    'blog-page-1' => array(
                        'sidebar_5',
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10',
                    )
                )
            ),
            '_404' => array(
                'layout_slug' => 'error-404',
                'sidebars' => array(
                    'error-404' => array(
                        'sidebar_7',
                        'sidebar_8',
                        'sidebar_9',
                        'sidebar_10'
                    )
                )
            )
        );
        $kopa_sidebar = KopaInit::get_sidebars();
        update_option(KOPA_OPT_PREFIX . 'layout_settings', $kopa_setting);
        update_option(KOPA_OPT_PREFIX . 'database_setup', KOPA_INIT_VERSION);
        //if (KOPA_DOMAIN . '-layout-setting-v1' == KOPA_INIT_VERSION) {
        update_option(KOPA_OPT_PREFIX . 'sidebars', $kopa_sidebar);
        //}
        $saved_opts = get_option(KOPA_OPT_PREFIX . 'options');
        if (!$saved_opts) {
            $tabs = KopaInit::get_theme_option_fields();
            $opts = array();
            foreach ($tabs as $tab) {
                foreach ($tab['groups'] as $groups) {
                    foreach ($groups['fields'] as $field) {
                        kopa_save_theme_options_loop($field, $opts);
                    }
                }
            }
            update_option(KOPA_OPT_PREFIX . 'options', $opts);
        }
    }
    $sidebars = get_option(KOPA_OPT_PREFIX . 'sidebars');
    foreach ($sidebars as $key => $value) {
        if ('sidebar_hide' != $key) {
            $sidebar_args = KopaInit::get_sidebar_args();
            $sidebar_args['name'] = $value;
            $sidebar_args['id'] = $key;
            register_sidebar($sidebar_args);
        }
    }
}
