<?php
add_action('after_setup_theme', 'kopa_widgets_after_setup_theme');

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0         
 */
function kopa_widgets_after_setup_theme() {
    if (is_admin()) {
        add_action('in_widget_form', 'kopa_widgets_in_widget_form', 5, 3);
        add_filter('widget_update_callback', 'kopa_widgets_in_widget_form_update', 5, 3);
    } else {
        add_filter('dynamic_sidebar_params', 'kopa_widgets_dynamic_sidebar_params');
    }
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_widgets_in_widget_form($t, $return, $instance) {
    if (in_array($t->id_base, array('kopa-scrollbar-widget', 'kopa-tab-3-widget', 'kopa-tab-1-widget', 'kopa-video-playlist')))
        return array($t, $return, $instance);

    $default = array(
        'widget_prefix_icon' => ''
    );
    $instance = wp_parse_args((array) $instance, $default);

    $icon = array(
        'title' => __('Widget title (bonus)', kopa_get_domain()),
        'help' => NULL,
        'fields' => array()
    );
    $icon['fields'][] = array(
        'type' => 'icon',
        'id' => 'widget_prefix_icon',
        'name' => 'widget_prefix_icon',
        'default' => '',
        'classes' => array(),
        'label' => NULL,
        'help' => NULL
    );
    $icon['fields'][] = array(
        'type' => 'text',
        'id' => 'widget_more_text',
        'name' => 'widget_more_text',
        'default' => __('All articles', kopa_get_domain()),
        'classes' => array(),
        'label' => __('Sub title', kopa_get_domain()),
        'help' => NULL
    );
    $icon['fields'][] = array(
        'type' => 'text',
        'id' => 'widget_more_link',
        'name' => 'widget_more_link',
        'default' => '',
        'classes' => array(),
        'label' => __('Sub title link', kopa_get_domain()),
        'help' => NULL
    );
    $groups = array(
        'bonus-widget-title' => $icon
    );
    foreach ($groups as $key => $group) {
        ?>
        <div class="kopa-widget-bonus-wrap">
            <p class="kopa-widget-bonus-caption clearfix">
                <?php echo $group['title']; ?>
                <?php
                $group_checked = '';
                $group_inner_style = 'display: none;';
                if (isset($instance[$key]) && ('true' == $instance[$key])) {
                    $group_checked = 'checked=checked';
                    $group_inner_style = 'display: block;';
                }
                ?>
                <input onclick="KopaWidget.clickBonusSection(event, jQuery(this));" <?php echo $group_checked; ?> class="pull-right" type="checkbox" value="true" name="<?php echo $t->get_field_name($key); ?>" id="<?php echo $t->get_field_name($key); ?>">
                <?php printf('<i>%s</i>', $group['help']); ?>
            </p>
            <div class="kopa-widget-bonus-inner" style="<?php echo $group_inner_style; ?>">
                <?php
                $i = 0;
                foreach ($group['fields'] as $field) {
                    $field_value = '';
                    if (isset($instance[$field['name']])){
                       $field_value = $instance[$field['name']];
                    }
                    $field['value'] = $field_value;
                    $wrap_classes = array('kopa-widget-control-wrap', 'clearfix');
                    $wrap_classes[] = (0 == $i % 2) ? 'even' : 'odd';
                    $field['wrap_begin'] = sprintf('<div class="%1$s">', implode(' ', $wrap_classes));
                    $field['wrap_end'] = '</div>';
                    $field['id'] = $t->get_field_id($field['id']);
                    $field['name'] = $t->get_field_name($field['name']);
                    $i++;
                    echo KopaControl::get_html($field);
                }
                ?>
            </div>
        </div>
        <?php
    }
    ?>
    <?php
    return array($t, $return, $instance);
}

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0
 */
function kopa_widgets_in_widget_form_update($instance, $new_instance, $old_instance) {
    if (isset($new_instance['widget_prefix_icon']))
        $instance['widget_prefix_icon'] = $new_instance['widget_prefix_icon'];

    if (isset($new_instance['bonus-widget-title']))
        $instance['bonus-widget-title'] = isset($new_instance['bonus-widget-title']) ? 'true' : 'false';

    if (isset($new_instance['widget_more_text']))
        $instance['widget_more_text'] = $new_instance['widget_more_text'];

    if (isset($new_instance['widget_more_link']))
        $instance['widget_more_link'] = $new_instance['widget_more_link'];

    return $instance;
}

function kopa_widgets_dynamic_sidebar_params($params) {

    global $wp_registered_widgets;
    $widget_id = $params[0]['widget_id'];
    $widget_obj = $wp_registered_widgets[$widget_id];
    $widget_opt = get_option($widget_obj['callback'][0]->option_name);
    $widget_num = $widget_obj['params'][0]['number'];

    if (isset($widget_opt[$widget_num]['bonus-widget-title'])) {
        if (!empty($widget_opt[$widget_num]['widget_prefix_icon'])) {
            $params[0]['before_title'] .= sprintf('<span class="icon-title %s"></span>', $widget_opt[$widget_num]['widget_prefix_icon']);
        }

        if (!empty($widget_opt[$widget_num]['widget_more_text']) &&  !empty($widget_opt[$widget_num]['widget_more_link'])) {
            $params[0]['after_title'] = sprintf('<a href="%s">%s</a>', $widget_opt[$widget_num]['widget_more_link'], $widget_opt[$widget_num]['widget_more_text']) . $params[0]['after_title'];
        }
    }

    return $params;
}

add_action('widgets_init', 'kopa_widgets_init');

/**
 * @package Kopa
 * @subpackage Core
 * @author thethangtran <tranthethang@gmail.com>
 * @since 1.0.0         
 */
function kopa_widgets_init() {
    $widgets = array(
        'KopaPosts_TabsByGroup_SmallThumb',
        'KopaPosts_List_SquareThumbnail',
    );
    #GALLERY
    $widgets[] = 'KopaPosts_GalleryGrid';
    $widgets[] = 'KopaPosts_GalleryList';

    #VIDEO
    $widgets[] = 'KopaPosts_VideoGrid';
    $widgets[] = 'KopaPosts_VideoPlaylist';

    #SOCIALS
    $widgets[] = 'KopaFlickr';

    #OTHER
    $widgets[] = 'KopaAdvertisement';

    $widgets = apply_filters('kopa_widgets_init', $widgets);

    if (!empty($widgets)) {
        foreach ($widgets as $widget) {
            register_widget($widget);
        }
    }
}
