<?php

class KopaPosts_GalleryGrid extends KopaWidgetPosts {

    public function __construct($id_base = '', $name = '', $widget_options = array(), $control_options = array()) {
        $id_base = 'kopa-gallery-list';
        $name = __('Kopa Gallery Grid', kopa_get_domain());
        $widget_options = array('classname' => 'kopa-gallery-list', 'description' => __('Display gallery by layout grid (masonry)', kopa_get_domain()));
        $control_options = array('width' => '500', 'height' => 'auto');
        parent::__construct($id_base, $name, $widget_options, $control_options);

        unset($this->groups['col-1']['fields']['excerpt_character_limit']);
        unset($this->groups['col-1']['fields']['is_hide_excerpt']);
        unset($this->groups['col-1']['fields']['is_hide_readmore']);
        unset($this->groups['col-1']['fields']['is_hide_views']);
        unset($this->groups['col-2']['fields']['relation']);
        unset($this->groups['col-2']['fields']['post_format']);

        $col_3 = array(
            'size' => 12,
            'fields' => array()
        );

        $col_3['fields']['layout'] = array(
            'type' => 'select',
            'id' => 'layout',
            'name' => 'layout',
            'default' => 'col-sm-4',
            'classes' => array(),
            'label' => __('Layout', kopa_get_domain()),
            'help' => NULL,
            'options' => array(
                'col-sm-6' => __('2 cols', kopa_get_domain()),
                'col-sm-4' => __('3 cols', kopa_get_domain()),
                'col-sm-3' => __('4 cols', kopa_get_domain()),
                'col-sm-2' => __('6 cols', kopa_get_domain())
            )
        );
        $this->groups['col-3'] = $col_3;
    }

    public function widget($args, $instance) {
        extract($args);

        $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
        $layout = isset($instance['layout']) ? $instance['layout'] : 'col-sm-4';

        echo $before_widget;
        if (!empty($title)) {
            echo $before_title . $title . $after_title;
        }

        $post_formats = get_terms('post_format');
        foreach ($post_formats as $format) {
            if ('post-format-gallery' == $format->slug) {
                $instance['post_format'] = $format->term_id;
                break;
            }
        }
        $instance['relation'] = 'true';
        $query = $this->build_query($instance);

        global $post;

        $posts = new WP_Query($query);
        if ($posts->have_posts()):
            $metadata = array();
            $metadata['is_hide_created_date'] = filter_var($instance['is_hide_created_date'], FILTER_VALIDATE_BOOLEAN);
            $metadata['is_hide_comments'] = filter_var($instance['is_hide_comments'], FILTER_VALIDATE_BOOLEAN);
            $metadata['is_hide_title'] = filter_var($instance['is_hide_title'], FILTER_VALIDATE_BOOLEAN);
            ?>
            <div class="gallery-masonry-wrap">
                <ul class="row clearfix">
                    <?php
                    while ($posts->have_posts()):
                        $posts->the_post();
                        $post_id = get_the_ID();
                        $post_title = get_the_title();
                        $post_url = get_permalink();
                        $post_format = get_post_format();

                        $post_classes = array('gl-item', $layout);
                        $image_size = 'size_10';
                        ?>

                        <li <?php post_class($post_classes); ?>>
                            <article class="entry-item clearfix">
                                <?php if (has_post_thumbnail()): ?>
                                    <?php $image = KopaImage::get_post_image_src($post_id, $image_size); ?>
                                    <div class="entry-thumb">
                                        <a href="<?php echo $post_url; ?>" title="<?php echo $post_title; ?>"><img src="<?php echo $image; ?>" alt="<?php echo $post_title; ?>"></a>

                                        <div class="thumb-hover">
                                            <div class="thumb-icon">
                                                <span class="icon-top"></span>
                                                <a href="<?php echo $post_url; ?>" title="<?php echo $post_title; ?>" class="magnific-gallery-trigger fa fa-picture-o"></a>
                                            </div>
                                        </div>
                                        <div class="hidden magnific-gallery">
                                            <?php
                                            $galleries = KopaUtil::get_shortcode($post->post_content, false, array('gallery'));

                                            if (isset($galleries[0]['atts']['ids'])) {
                                                $ids = explode(',', $galleries[0]['atts']['ids']);
                                                if (!empty($ids)) {
                                                    foreach ($ids as $id) {
                                                        $image = wp_get_attachment_image_src($id, 'full');
                                                        printf('<a href="%s" title="%s"></a>', $image[0], get_post_field('post_excerpt', $id));
                                                    }
                                                }
                                            }
                                            ?>
                                        </div>
                                    </div>
                                <?php endif; ?>

                                <div class="entry-content">
                                    <?php if (!$metadata['is_hide_title'] && !empty($post_title) ): ?>
                                        <h4 class="entry-title"><a href="<?php echo $post_url; ?>" title="<?php echo $post_title; ?>"><?php echo $post_title; ?></a></h4>
                                    <?php endif; ?>

                                    <?php if (!$metadata['is_hide_created_date'] || !$metadata['is_hide_comments']): ?>
                                        <p class="entry-date">
                                            <?php if (!$metadata['is_hide_created_date']): ?>
                                                <?php echo $metadata['is_hide_comments'] ? __('Posted:', kopa_get_domain()) . '&nbsp;' : ''; ?>
                                                <span><?php echo get_the_date(); ?></span>
                                            <?php endif; ?>

                                            <?php if (!$metadata['is_hide_comments']): ?>
                                                <?php echo $metadata['is_hide_created_date'] ? '' : '&nbsp;-&nbsp;'; ?>                                            
                                                <?php comments_popup_link(__('No Comment', kopa_get_domain()), __('1 Comment', kopa_get_domain()), __('% Comments', kopa_get_domain()), '', __('0 Comment', kopa_get_domain())); ?>
                                            <?php endif; ?>
                                        </p>
                                    <?php endif; ?>
                                </div>

                            </article>
                        </li>

                        <?php
                    endwhile;
                    ?>
                </ul>
            </div>    
            <?php
        endif;
        wp_reset_postdata();

        echo $after_widget;
    }

}
