<?php

class KopaPosts_GalleryList extends KopaWidgetPosts {

    public function __construct($id_base = '', $name = '', $widget_options = array(), $control_options = array()) {
        $id_base = 'kopa-gallery-list-one-col';
        $name = __('Kopa Gallery List', kopa_get_domain());
        $widget_options = array('classname' => 'kopa-gallery-top', 'description' => __('Display gallery by layout one column', kopa_get_domain()));
        $control_options = array('width' => '500', 'height' => 'auto');
        parent::__construct($id_base, $name, $widget_options, $control_options);

        unset($this->groups['col-1']['fields']['is_hide_readmore']);
        unset($this->groups['col-1']['fields']['is_hide_views']);
        unset($this->groups['col-2']['fields']['relation']);
        unset($this->groups['col-2']['fields']['post_format']);

        $this->groups['col-1']['fields']['is_hide_category'] = array(
            'type' => 'checkbox',
            'id' => 'is_hide_category',
            'name' => 'is_hide_category',
            'default' => 'false',
            'classes' => array(),
            'label' => __('Is hide category', kopa_get_domain()),
            'help' => NULL,
            'is_append_label_before_control' => false
        );
    }

    public function widget($args, $instance) {
        extract($args);

        $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);

        echo $before_widget;
        if (!empty($title)) {
            echo $before_title . $title . $after_title;
        }

        $post_formats = get_terms('post_format');
        foreach ($post_formats as $format) {
            if ('post-format-gallery' == $format->slug) {
                $instance['post_format'] = $format->term_id;
                break;
            }
        }
        $instance['relation'] = 'true';
        $query = $this->build_query($instance);

        $posts = new WP_Query($query);
        if ($posts->have_posts()):
            $metadata = array();
            $metadata['is_hide_created_date'] = filter_var($instance['is_hide_created_date'], FILTER_VALIDATE_BOOLEAN);            
            $metadata['is_hide_title'] = filter_var($instance['is_hide_title'], FILTER_VALIDATE_BOOLEAN);
            $metadata['is_hide_category'] = filter_var($instance['is_hide_category'], FILTER_VALIDATE_BOOLEAN);
            $metadata['is_hide_comments'] = filter_var($instance['is_hide_comments'], FILTER_VALIDATE_BOOLEAN);

            $is_first = true;

            global $post;

            while ($posts->have_posts()):
                $posts->the_post();
                $post_id = get_the_ID();
                $post_title = get_the_title();
                $post_url = get_permalink();
                $post_format = get_post_format();

                $post_classes = array('clearfix');
                $image_size = 'size_10';

                $post_classes[] = $is_first ? 'kopa-gallery-list-first' : 'kopa-gallery-list-other';
                ?>

                <article <?php post_class($post_classes); ?>>
                    <?php
                    $shortcode = KopaUtil::get_shortcode($post->post_content, false, array('gallery'));
                    if ($shortcode && isset($shortcode[0]['atts']) && !empty($shortcode[0]['atts'])):
                        $ids = explode(',', $shortcode[0]['atts']['ids']);
                        ?>
                        <div class="gallery-carousel">
                            <div class="owl-carousel owl-carousel4">
                                <?php
                                foreach ($ids as $id):
                                    $image = wp_get_attachment_image_src($id, 'full');
                                    $image_thumb = KopaImage::get_image_src($image[0], 'size_14');
                                    $caption = get_post_field('post_excerpt', $id);
                                    ?>
                                    <div class="item">
                                        <img src="<?php echo $image_thumb; ?>" alt="<?php echo $caption; ?>">  
                                    </div>                                
                                <?php endforeach; ?>
                            </div>
                        </div>
                        <!--/end gallery-carousel-->  
                    <?php endif; ?>

                    <div class="gallery-post-content media-body">
                        <header>
                            <span class="icon-top fa fa-picture-o"></span> 
                            <?php if ( ! empty($post_title) ) : ?>
                                <h4 class="entry-title"><a href="<?php echo $post_url; ?>" title="<?php echo $post_title; ?>"><?php echo $post_title; ?></a></h4>
                            <?php endif; ?>
                            <div class="entry-meta clearfix">
                                <?php
                                foreach ($metadata as $key => $val) {
                                    if (!$val) {
                                        switch ($key) {
                                            case 'is_hide_created_date':
                                                printf('<p class="entry-date">%s<span>%s</span></p>', __('Posted:', kopa_get_domain()), get_the_date());
                                                break;
                                            case 'is_hide_comments':
                                                ?>
                                                <p class="entry-comment"><?php comments_popup_link(__('No Comment', kopa_get_domain()), __('1 Comment', kopa_get_domain()), __('% Comments', kopa_get_domain()), '', __('0 Comment', kopa_get_domain())); ?></p>
                                                <?php
                                                break;
                                            case 'is_hide_category':
                                                KopaUtil::get_the_terms($post_id, 'category', '<p class="entry-categories">' . __('in:', kopa_get_domain()) . '&nbsp;', '</p>', ', ');
                                                break;
                                        }
                                    }
                                }
                                ?>
                            </div>
                        </header>

                        <?php
                        if (!filter_var($instance['is_hide_excerpt'], FILTER_VALIDATE_BOOLEAN)) {
                            if ((int) $instance['excerpt_character_limit'] > 0) {
                                $excerpt = KopaUtil::substr($post->post_content, (int) $instance['excerpt_character_limit']);
                                echo ($excerpt) ? sprintf('<p>%s</p>', $excerpt) : '';
                            } else {
                                the_excerpt();
                            }
                        }
                        ?>
                    </div>

                    <!--/end gallery-carousel-->    
                </article>

                <?php
                $is_first = false;
            endwhile;
        endif;
        wp_reset_postdata();

        echo $after_widget;
    }

}
