<?php

class KopaPosts_VideoGrid extends KopaWidgetPosts {

    public function __construct($id_base = '', $name = '', $widget_options = array(), $control_options = array()) {
        $id_base = 'kopa-video-list';
        $name = __('Kopa Video Grid', kopa_get_domain());
        $widget_options = array('classname' => 'kopa-video-list', 'description' => __('Display videos by layout grid (masonry)', kopa_get_domain()));
        $control_options = array('width' => '500', 'height' => 'auto');
        parent::__construct($id_base, $name, $widget_options, $control_options);


        unset($this->groups['col-1']['fields']['excerpt_character_limit']);
        unset($this->groups['col-1']['fields']['is_hide_excerpt']);
        unset($this->groups['col-1']['fields']['is_hide_readmore']);
        unset($this->groups['col-1']['fields']['is_hide_views']);
        unset($this->groups['col-2']['fields']['relation']);
        unset($this->groups['col-2']['fields']['post_format']);


        $col_3 = array(
            'size' => 12,
            'fields' => array()
        );

        $col_3['fields']['col-3-divider'] = array(
            'type' => 'custom',
            'id' => 'col-3-divider',
            'name' => 'col-3-divider',
            'default' => 'false',
            'html' => '<hr>'
        );

        $col_3['fields']['is_hightlight_first'] = array(
            'type' => 'checkbox',
            'id' => 'is_hightlight_first',
            'name' => 'is_hightlight_first',
            'default' => 'false',
            'classes' => array(),
            'label' => __('Is hightlight the first video', kopa_get_domain()),
            'help' => NULL,
            'is_append_label_before_control' => false
        );

        $this->groups['col-3'] = $col_3;
    }

    public function widget($args, $instance) {
        extract($args);

        $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);

        echo $before_widget;
        if (!empty($title)) {
            echo $before_title . $title . $after_title;
        }

        $post_formats = get_terms('post_format');
        foreach ($post_formats as $format) {
            if ('post-format-video' == $format->slug) {
                $instance['post_format'] = $format->term_id;
                break;
            }
        }
        $instance['relation'] = 'true';
        $query = $this->build_query($instance);

        $posts = new WP_Query($query);
        if ($posts->have_posts()):
            global $post;

            $metadata = array();
            $metadata['is_hide_created_date'] = filter_var($instance['is_hide_created_date'], FILTER_VALIDATE_BOOLEAN);
            $metadata['is_hide_comments'] = filter_var($instance['is_hide_comments'], FILTER_VALIDATE_BOOLEAN);
            $metadata['is_hide_title'] = filter_var($instance['is_hide_title'], FILTER_VALIDATE_BOOLEAN);
            $metadata['is_hightlight_first'] = filter_var($instance['is_hightlight_first'], FILTER_VALIDATE_BOOLEAN);
            ?>
            <div class="video-masonry-wrap">
                <ul class="clearfix">
                    <?php
                    $is_first = true;

                    while ($posts->have_posts()):
                        $posts->the_post();
                        $post_id = get_the_ID();
                        $post_title = get_the_title();
                        $post_url = get_permalink();
                        $post_format = get_post_format();

                        $post_classes = array('list-video-item');
                        $image_size = 'size_10';
                        if ($is_first && $metadata['is_hightlight_first']) {
                            $post_classes[] = 'last-item';
                            $image_size = 'size_17';
                        }
                        ?>
                        <li <?php post_class($post_classes); ?>>
                            <article class="entry-item">
                                <?php if (has_post_thumbnail()): ?>
                                    <?php $image = KopaImage::get_post_image_src($post_id, $image_size); ?>
                                    <div class="entry-thumb">
                                        <a href="<?php echo $post_url; ?>" title="<?php echo $post_title; ?>"><img src="<?php echo $image; ?>" alt="<?php echo $post_title; ?>"></a>

                                        <?php
                                        $videos = KopaUtil::get_shortcode($post->post_content, false, array('vimeo', 'youtube', 'video'));
                                        if (!empty($videos)) {
                                            $video = $videos[0];

                                            if (in_array($video['type'], array('youtube', 'vimeo'))) {
                                                if (isset($video['atts']['id']) && !empty($video['atts']['id'])) {
                                                    $video_url = sprintf('http://vimeo.com/%s', $video['atts']['id']);

                                                    if ('youtube' == $video['type']) {
                                                        $video_url = sprintf('http://www.youtube.com/watch?v=%s', $video['atts']['id']);
                                                    }

                                                    $lightbox_classes = 'magnific_youtube_or_vimeo';
                                                }
                                            } else if ('video' == $video['type']) {
                                                $video_url = sprintf('%s&action=%s&post_id=%s&post_format=%s', wp_nonce_url(admin_url('admin-ajax.php'), 'kopa_load_post', 'ajax_nonce'), 'kopa_load_post', $post_id, $post_format);
                                                $lightbox_classes = 'magnific_ajax';
                                            }
                                        } else {
                                            $video_url = $post_url;
                                        }
                                        ?>

                                        <a class="<?php echo $lightbox_classes; ?> fa fa-play" href="<?php echo esc_url($video_url); ?>" title="<?php echo $post_title; ?>"></a>
                                    </div> 
                                <?php endif; ?>
                                <div class="entry-content">
                                    <?php if (!$metadata['is_hide_title'] && ! empty($post_title) ): ?>
                                        <h4 class="entry-title"><a href="<?php echo $post_url; ?>" title="<?php echo $post_title; ?>"><?php echo $post_title; ?></a></h4>
                                    <?php endif; ?>

                                    <?php if (!$metadata['is_hide_created_date'] || !$metadata['is_hide_comments']): ?>
                                        <p class="entry-date">
                                            <?php if (!$metadata['is_hide_created_date']): ?>
                                                <?php echo $metadata['is_hide_comments'] ? __('Posted:', kopa_get_domain()) . '&nbsp;' : ''; ?>
                                                <span><?php echo get_the_date(); ?></span>
                                            <?php endif; ?>

                                            <?php if (!$metadata['is_hide_comments']): ?>
                                                <?php echo $metadata['is_hide_created_date'] ? '' : '&nbsp;-&nbsp;'; ?>                                            
                                                <?php comments_popup_link(__('No Comment', kopa_get_domain()), __('1 Comment', kopa_get_domain()), __('% Comments', kopa_get_domain()), '', __('0 Comment', kopa_get_domain())); ?>
                                            <?php endif; ?>
                                        </p>
                                    <?php endif; ?>
                                </div>
                            </article>
                        </li>
                        <?php
                        $is_first = false;
                    endwhile;
                    ?>
                </ul>
            </div>    
            <?php
        endif;
        wp_reset_postdata();

        echo $after_widget;
    }

}
